System.register([], (function () {
	'use strict';
	return {
		execute: (function () {

			const hs = document.documentElement.style;

			{
				hs.color = "#222";
			}

		})
	};
}));
